ATTENTION, SI VOUS MODIFIEZ CE POINT, CERTAINES BALISES PEUVENT DISPARAITRE EN FONCTION DE LA CONFIGURATION DE CKEDITOR (PS: ce texte utilise la class CSS "highlight-red")

Idéalement utiliser un modèle dont le style par défaut a été redéfini, ceci permet de tester qu'un paragraphe utilisant un style est rendu avec le même style (Poice et taille de police) qu'un paragraphe sans style

Pour tester l'utilisation du style "Signature" il faut également le redéfinir dans le modèle et lui adjoindre par exemple une couleur de fond

>>>>> TEXTE <<<<< :

Du texte avec du gras, de l'italique, du souligné, du barré, du gras souligné :

Un paragraphe utilisant un style ou n'en utilisant pas est rendu avec la même police/taille de police :

Du texte n'utilisant aucun style...

Du texte utilisant un style ajoutant un décalage margin-left:25px...

Utilisation des tags pour la mise en forme :

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné, NE FONCTIONNE PAS AVEC LIBREOFFICE4 EN WORD, TESTER EN LIBREOFFICE5;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné.

Utilisation de CSS pour la mise en forme :

style directement sur <li style=...>

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné.

style sur <p> dans <li>

- italique barré;

- italique gras;

- italique souligné;

- gras barré;

- gras souligné;

- gras italique barré;

- gras italique souligné;

- gras barré souligné;

- gras italique barré souligné.

style sur <span> dans <li>

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné.

Style défini sur un p contenu dans un li est transféré sur le li et gardé:

- attribut "style" italique gras;

- attribut "class" utilisant "Signature", un style par défaut de LibreOffice.

Texte avec espace entre chaque paragraphe :

Texte texte texte...

Texte texte texte...

Texte texte texte...

Texte texte texte...

Retrait en début de ligne :

Mon texte sans retrait

Mon texte avec retrait Mon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retrait

Mon texte utilisant text-indent, seule la première ligne du paragraphe est impactée par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait

Alignement du texte :

Paragraphe sans alignement

Paragraphe aligné à gauche

Paragraphe aligné à droite

Paragraphe centré

Long paragraphe justifié Long paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifié

Bloc de texte gardé sur la même page (fonctionne si le style "pmParaKeepWithNext" est défini dans le modèle ODT):

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Retrait en début de ligne négatif :

Mon texte avec retrait de margin-left:-1cm;

Mon texte avec retrait de margin-left:-.75pt;

Texte avec nombreux espaces avant :

Mon texte

Aligné manuellement

>>>>> TITRES (Titre1, Titre2, ...) <<<<< :

# Titre1 Titre1 Titre1

## Titre2 Titre2 Titre2

### Titre3 Titre3 Titre3

#### Titre4 Titre4 Titre4

##### Titre5 Titre5 Titre5

###### Titre6 Titre6 Titre6

>>>>> PUCES CLASSIQUES <<<<< :

- puce normale;

- puce contenue dans un <p>;

- puce barrée contenue dans un <p>;

  - sous-puce;

  - sous-puce soulignée;

  - sous-puce barrée;

    - sous-sous-puce gras;

    - sous-sous-puce;

- les puces avec formattage sont testées ci-dessus;

>>>>> PUCES NUMEROTEES <<<<< :

Numérotation classique :

1. Texte texte gras;
2. Texte texte souligné;
3. Texte gras/italique/souligné/barré texte;
4. Texte texte texte;
5. Texte texte texte;

Avec sous-numérotation :

1. Texte texte texte;
2. Texte italique texte;
   1. Texte souligné;

   2. Texte gras texte dans un <p>;

   3. Texte texte texte dans un <p> et barré;

3. Texte texte texte;
4. Texte texte texte;
5. Texte texte texte;

Numérotation chiffres et lettres :

1. Texte gras barré;
2. Texte texte text;
   1. sous-puce lettre minuscule, Texte texte text;
   2. Texte texte text;
   3. Texte texte text;
3. Texte texte text;
4. Texte texte text;
   1. sous-puce lettre MAJUSCULE utilisant un "b" au lieu d'un "strong" pour le gras, Texte texte text;
   2. Texte texte text;
5. Texte texte text;

Renumérotation :

1. Texte texte text;
2. Texte texte text;
3. Texte texte text;

Du texte inséré dans la liste (avec un margin-left sur le <p>) puis...

4. On recommence à 4;
5. Texte texte text;
   1. Texte texte texte;
   2. Texte texte texte;
   3. Texte texte texte;
6. Texte texte text;

Puces numérotées et classiques :

1. Texte texte texte;
2. Texte texte texte;
   - Texte texte texte;
   - Texte texte texte;
3. Texte texte texte;
4. Texte texte texte;

Puces contenant structure complexe :

- Texte contenu dans un li/div/p

- Texte contenu dans un li/p/u/b

- Texte contenu dans un li/div/p

>>>>>>>>>>>>>>> TABLEAUX <<<<<<<<<<<<<<< :

Les tableaux >= 500px sont affichés en 100% dans le document produit.

Tableau de 250px :

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Tableau complexe de 17cm de large :

Couleur de fond en rgb(), en #123123 et en HTML color.

TEXTE CENTRE ET GRAS
Né(e) le : ..., Etat civil : ...
CENTRE, GRAS ET SOULIGNE

Utilisation de "colspan" |
Couleur de fond RGB, text centré, utilisation de "rowspan" | Souligné | DUREE PAR GROUPE | Coef- ficient | VALORISATION BAREMIQUE
Couleur fond hexa | Couleur fond HTML color | du | au | ANS | MOIS |  | ANS | MOIS
|  |  |  |  |  | TOTAL: |  |
Texte... |  |
Augmentation les ... |  |

Tableau avec nombreuses colonnes, taille de texte réduite en utilisant "font-size: 9px" et "font-size: 8px", cellspacing="0", headers du tableau en gras en utilisant "font-weight: bold" :

Température | Janvier | Février | Mars | Avril | Mai | Juin | Juillet | Août | Septembre | Octobre | Novembre | Décembre
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Les cinq mois les plus chauds | 1975 | 6.3 | 1990 | 7.9 | 1991 | 9.5 | 1987 | 11.9 | 1947 | 15.8 | 1976 | 19.3 | 1994 | 21.8 | 1997 | 21.2 | 1949 | 17.7 | 1921 | 14.0 | 1994 | 10.4 | 1934 | 7.5
1921 | 6.2 | 1926 | 7.6 | 1957 | 9.5 | 1993 | 11.8 | 1989 | 15.8 | 1950 | 18.1 | 1983 | 21.2 | 1911 | 20.9 | 1999 | 17.7 | 1995 | 13.7 | 1984 | 9.4 | 1974 | 7.0
1988 | 6.2 | 1961 | 7.2 | 1989 | 9.1 | 1961 | 11.7 | 1992 | 15.7 | 1970 | 17.9 | 1995 | 20.9 | 1995 | 20.4 | 1961 | 17.3 | 1989 | 12.7 | 1938 | 9.0 | 1988 | 6.9
1916 | 6.1 | 1995 | 6.8 | 1981 | 9.1 | 1952 | 11.5 | 1998 | 15.6 | 1947 | 17.8 | 1976 | 20.0 | 1947 | 20.4 | 1947 | 17.0 | 1990 | 12.6 | 1963 | 8.8 | 1915 | 6.3
1983 | 5.9 | 1966 | 6.6 | 1990 | 8.7 | 1949 | 11.2 | 1917 | 15.5 | 1986 | 17.5 | 1999 | 19.7 | 1990 | 19.7 | 1982 | 16.9 | 1969 | 12.6 | 1913 | 8.7 | 1918 | 6.3
normales |  | 2.5 |  | 3.0 |  | 5.9 |  | 8.7 |  | 12.8 |  | 15.3 |  | 17.0 |  | 16.9 |  | 14.4 |  | 10.3 |  | 5.8 |  | 3.3
Les cinq mois les plus froids | 1985 | -2.8 | 1947 | -3.2 | 1971 | 3.2 | 1908 | 6.2 | 1984 | 10.4 | 1991 | 13.2 | 1965 | 14.4 | 1941 | 15.0 | 1986 | 11.7 | 1992 | 7.8 | 1993 | 2.8 | 1963 | -0.5
1987 | -2.8 | 1986 | -3.2 | 1987 | 3.1 | 1970 | 6.2 | 1991 | 10.4 | 1909 | 13.1 | 1913 | 14.3 | 1956 | 14.4 | 1931 | 11.6 | 1919 | 7.1 | 1915 | 2.7 | 1969 | -0.5
1942 | -3.6 | 1942 | -3.5 | 1955 | 2.7 | 1929 | 6.0 | 1962 | 10.2 | 1956 | 12.6 | 1909 | 14.2 | 1920 | 14.3 | 1925 | 11.5 | 1974 | 6.8 | 1925 | 2.7 | 1927 | -0.6
1940 | -4.2 | 1929 | -3.6 | 1962 | 2.7 | 1903 | 5.3 | 1941 | 9.8 | 1916 | 12.2 | 1907 | 13.6 | 1924 | 14.2 | 1952 | 11.2 | 1922 | 6.5 | 1919 | 2.5 | 1950 | -1.2
1963 | -4.6 | 1956 | -6.1 | 1917 | 2.5 | 1917 | 4.6 | 1902 | 8.5 | 1923 | 11.5 | 1919 | 13.5 | 1912 | 13.8 | 1912 | 10.7 | 1905 | 5.9 | 1921 | 1.8 | 1933 | -2.7

Tableau avec gras défini sur première ligne, vérifier que les lignes 2 et 3 ne sont pas en gras (problème génération Word Ooo4).

1 | Texte texte texte texte texte texte texte texte
2 | Texte sans gras sans gras
3 | Texte sans gras sans gras

Tableau avec largeur fixée à 1000px et 4ème cellule fixée à 200px, mal rendu dans Oo5 :

Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
--- | --- | --- | --- | ---
lignes de textes dans des <p> différents, saut de ligne gardé seconde ligne dans un <p> troisième ligne dans un <p> | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text

Tableau avec alignement vertical et horizontal :

Texte vertical haut | Texte centré texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte bas | Texte à droite texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte centré | Texte justifié texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte aligné à droite, style appliqué sur un p dans le td | Texte centré, style appliqué sur un p dans le td
Comportement par défaut | Texte par défaut texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte

Tableau une seule colonne avec couleurs de fond et couleur de texte :

Fond en RVB et texte vert
Dans un <p> fond en # et texte bleu, le <p> étant supprimé, le style color n'est pas gardé et le texte rendu n'est pas bleu
Dans un <span> fond en # et texte bleu, le <span> est gardé mais les styles pas...
Dans un <td> fond en # et texte bleu, les styles définis sur le <td> sont gardés
Fond en HTML color et texte gris

Tableau une seule colonne utilisé comme titre :

A. Description de la fonction

Tableau sans colonne de 1024px de large (non rendu) :

Tableau sans bordures (border="0") :

Texte 1.1; | Texte 1.2; | Texte 1.3;
Texte 2.1; | Texte 2.2; | Texte 2.3;

Tableau structure complexe table/td/div/p :

Texte contenu dans un td/div/p

Tableau utilisant des colspan sur la première ligne "inutilement" :

Texte | Texte

Tableau style défini sur un p contenu dans un td est transféré sur le td et gardé:

Texte utilisant attribut "style" gras; | Texte utilisant attribut "class" la classe par défaut "Signature".

>>>>> IMAGES <<<<< :

Cette image devrait être affichée dans le document généré, trop large elle est adaptée au document

Une petite image est affichée correctement

Image affichée sans width/height renseignés

Image utilisant un style="float: right;" (casse la génération en 0.9.4)

Image redimensionnée (plus petite) via les attributs "width=150px" et "height=75px", pas via "style='width:...; height:...;"

Une image redimensionnée dans l'éditeur est rendue redimensionnée

Image non trouvée externe

Image non trouvée interne

Une image utilisant un chemin de type file:/// ne casse pas la génération

>>>>> CAS SPECIAUX <<<<< :

Balise <pre> :

    Mon texte dans une balise pre

Balise <blockquote> :

> Mon texte dans une balise blockquote

> Mon blockquote contenant ce texte dans un <span> et

> ce texte dans un <p>

Balise <code> utilisée dans du texte :

Mon texte avec du code `dans une balise "code"`

Texte où les caractères accentués comme "à" sont en fait "a" + "`" :

Mon texte, ceci est un vrai "à", ceci n'est pas un vrai "à".

Texte avec un <span> contenant l'espace de début, celui-ci est gardé :

Mon texte puis texte avec espace devant du texte puis texte avec espace devant et du texte puis texte avec espace devant et derrière puis du texte.

Mon texte puis`texte avec espace devant` du texte puis`texte avec espace devant` et du texte puis`texte avec espace devant et derrière` puis du texte.